@@ -32,6 +32,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 import pygame
 import pygame_menu.locals as _locals
+import sys
 
 
 def assert_alignment(align):
@@ -172,3 +173,24 @@ def make_surface(width, height, alpha=False, fill_color=None):
         assert_color(fill_color)
         surface.fill(fill_color)
     return surface
+
+
+def to_string(s, strict=False):
+    """
+    Check if string, if not convert. See issue #215.
+    This function is compatible for py 2/3.
+
+    :param s: String
+    :type s: any
+    :param strict: If True, deny any unicode string if python 2
+    :type strict: bool
+    :return: String
+    :rtype: str
+    """
+    if isinstance(s, (str, bytes)):
+        return s
+    if sys.version_info < (3, 0) and str(type(s)) == "<type 'unicode'>":
+        if strict:
+            raise Exception("use a encoding for the unicode string, for example u'your_string'.encode('latin1')")
+        return s
+    return str(s)
